pub struct Time;Expand description
Time DType.
Implementations
Sourceimpl Time
impl Time
Sourcepub fn try_new(
time_unit: TimeUnit,
nullability: Nullability,
) -> VortexResult<ExtDType<Self>>
pub fn try_new( time_unit: TimeUnit, nullability: Nullability, ) -> VortexResult<ExtDType<Self>>
Creates a new Time extension dtype with the given time unit and nullability.
Note that only Milliseconds and Days time units are supported for Time.
Sourcepub fn new(time_unit: TimeUnit, nullability: Nullability) -> ExtDType<Self>
pub fn new(time_unit: TimeUnit, nullability: Nullability) -> ExtDType<Self>
Creates a new Time extension dtype with the given time unit and nullability.